from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='df_to_rs',
    version='0.1.1', # Incremented version number
    author='Ankit Goel',
    author_email='ankitgoel888@gmail.com',
    description='A simple library to upload pandas DataFrame to Redshift',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/yourusername/df_to_rs',
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'boto3',
        'pandas',
        'psycopg2',
    ],
    python_requires='>=3.6, <3.11',
)
